import numpy as np

dataset_map = {
    "2018ul": {
        "dataA": {
            "dataset": "/SingleMuon/Run2018A-UL2018_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL18_RunA_V5_DATA",
        },
        "dataB": {
            "dataset": "/SingleMuon/Run2018B-UL2018_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL18_RunB_V5_DATA",
        },
        "dataC": {
            "dataset": "/SingleMuon/Run2018C-UL2018_MiniAODv2_BParking-v2/MINIAOD",
            "jec_version": "Summer19UL18_RunC_V5_DATA",
        },
        "dataD": {
            "dataset": "/SingleMuon/Run2018D-UL2018_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL18_RunD_V5_DATA",
        },
        "common_data": {
            "good_run_json": "Collisions18/Cert_ABCD_13TeV_Legacy2018_Collisions18_JSON.txt",
            "roccor": "RoccoR2018UL.txt",
            "global_tag": "106X_dataRun2_v37",
        },
        "DYJetsToLL": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_M-10to50": {
            "dataset": "/DYJetsToLL_M-10to50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToMuMu": {
            "dataset": "/DYJetsToMuMu_H2ErratumFix_PDFExt_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToTauTau": {
            "dataset": "/DYJetsToTauTau_M-50_AtLeastOneEorMuDecay_H2ErratumFix_PDF_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_0J": {
            "dataset": "/DYJetsToLL_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "DYJetsToLL_1J": {
            "dataset": "/DYJetsToLL_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "DYJetsToLL_2J": {
            "dataset": "/DYJetsToLL_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_0To50": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-0To50_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_50To100": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-50To100_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_100To250": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-100To250_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_250To400": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-250To400_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_400To650": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-400To650_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_650ToInf": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-650ToInf_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYJetsToLL_MLM": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-madgraphMLM-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "DYToLL_herwig": {
            "dataset": "/DYToLL_NLO_5FS_TuneCH3_13TeV_matchbox_herwig7/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1_ext1-v2/MINIAODSIM"
        },
        "DYJetsToLL_herwig": {
            "dataset": "/DYJetsToLL_M-50_TuneCH3_13TeV-madgraphMLM-herwig7/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "WW": {
            "dataset": "/WW_TuneCP5_13TeV-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "WWTo2L2Nu": {
            "dataset": "/WWTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "WZ": {
            "dataset": "/WZ_TuneCP5_13TeV-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "WZTo3LNu": {
            "dataset": "/WZTo3LNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "WZTo2Q2L": {
            "dataset": "/WZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ZZ": {
            "dataset": "/ZZ_TuneCP5_13TeV-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ZZTo2Nu2Q": {
            "dataset": "/ZZTo2Nu2Q_5f_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v3/MINIAODSIM",
        },
        "ZZTo2L2Nu": {
            "dataset": "/ZZTo2L2Nu_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "ZZTo2Q2L": {
            "dataset": "/ZZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ZZTo4L": {
            "dataset": "/ZZTo4L_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ST_tw_top": {
            "dataset": "/ST_tW_top_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ST_tw_antitop": {
            "dataset": "/ST_tW_antitop_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "ST_t-channel_top": {
            "dataset": "/ST_t-channel_top_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "ST_t-channel_antitop": {
            "dataset": "/ST_t-channel_antitop_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "TTbar": {
            "dataset": "/TTTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "WJetsToLNu": {
            "dataset": "/WJetsToLNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM"
        },
        "WJetsToLNu_0J": {
            "dataset": "/WJetsToLNu_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "WJetsToLNu_1J": {
            "dataset": "/WJetsToLNu_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v1/MINIAODSIM",
        },
        "WJetsToLNu_2J": {
            "dataset": "/WJetsToLNu_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL18MiniAODv2-106X_upgrade2018_realistic_v16_L1v1-v2/MINIAODSIM",
        },
        "common_mc": {
            "good_run_json": "data/json/Collisions18/Cert_ABCD_13TeV_Legacy2018_Collisions18_JSON.txt",
            "data_pu_distribution": "data/pileup/data/data18_12Nov2019_UltraLegacy/pileup_latest.txt",
            "roccor": "RoccoR2018UL.txt",
            "jec_version": "Summer19UL18_V5_MC",
            "jer_version": "Summer19UL18_JRV2",
            "global_tag": "106X_upgrade2018_realistic_v16_L1v1",
        },
    },
    "2017ul": {
        "dataB": {
            "dataset": "/SingleMuon/Run2017B-UL2017_MiniAODv2-v1/MINIAOD",
            "jec_version": "Summer19UL17_RunB_V5_DATA",
        },
        "dataC": {
            "dataset": "/SingleMuon/Run2017C-UL2017_MiniAODv2-v1/MINIAOD",
            "jec_version": "Summer19UL17_RunC_V5_DATA",
        },
        "dataD": {
            "dataset": "/SingleMuon/Run2017D-UL2017_MiniAODv2-v1/MINIAOD",
            "jec_version": "Summer19UL17_RunD_V5_DATA",
        },
        "dataE": {
            "dataset": "/SingleMuon/Run2017E-UL2017_MiniAODv2-v1/MINIAOD",
            "jec_version": "Summer19UL17_RunE_V5_DATA",
        },
        "dataF": {
            "dataset": "/SingleMuon/Run2017F-UL2017_MiniAODv2-v1/MINIAOD",
            "jec_version": "Summer19UL17_RunF_V5_DATA",
        },
        "common_data": {
            "good_run_json": "Collisions17/Cert_BCDEF_13TeV_UL2017_Collisions17_GoldenJSON.txt",
            "roccor": "RoccoR2017UL.txt",
            "global_tag": "106X_dataRun2_v37",
        },
        "DYJetsToLL": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_M-10to50": {
            "dataset": "/DYJetsToLL_M-10to50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToMuMu": {
            "dataset": "/DYJetsToMuMu_H2ErratumFix_PDFExt_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToTauTau": {
            "dataset": "/DYJetsToTauTau_M-50_AtLeastOneEorMuDecay_H2ErratumFix_PDF_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_0J": {
            "dataset": "/DYJetsToLL_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_1J": {
            "dataset": "/DYJetsToLL_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_2J": {
            "dataset": "/DYJetsToLL_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_0To50": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-0To50_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_50To100": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-50To100_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_100To250": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-100To250_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_250To400": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-250To400_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_400To650": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-400To650_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v4/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_650ToInf": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-650ToInf_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_MLM": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-madgraphMLM-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "DYJetsToLL_herwig": {
            "dataset": "/DYJetsToLL_M-50_TuneCH3_13TeV-madgraphMLM-herwig7/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "WW": {
            "dataset": "/WW_TuneCP5_13TeV-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "WWTo2L2Nu": {
            "dataset": "/WWTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "WZ": {
            "dataset": "/WZ_TuneCP5_13TeV-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "WZTo2Q2L": {
            "dataset": "/WZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "WZTo3LNu": {
            "dataset": "/WZTo3LNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ZZ": {
            "dataset": "/ZZ_TuneCP5_13TeV-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "ZZTo2Nu2Q": {
            "dataset": "/ZZTo2Nu2Q_5f_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ZZTo2L2Nu": {
            "dataset": "/ZZTo2L2Nu_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "ZZTo2Q2L": {
            "dataset": "/ZZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ZZTo4L": {
            "dataset": "/ZZTo4L_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ST_tw_top": {
            "dataset": "/ST_tW_top_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ST_tw_antitop": {
            "dataset": "/ST_tW_antitop_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "ST_t-channel_top": {
            "dataset": "/ST_t-channel_top_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "ST_t-channel_antitop": {
            "dataset": "/ST_t-channel_antitop_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "TTbar": {
            "dataset": "/TTTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "WJetsToLNu": {
            "dataset": "/WJetsToLNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM"
        },
        "WJetsToLNu_0J": {
            "dataset": "/WJetsToLNu_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "WJetsToLNu_1J": {
            "dataset": "/WJetsToLNu_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v2/MINIAODSIM",
        },
        "WJetsToLNu_2J": {
            "dataset": "/WJetsToLNu_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL17MiniAODv2-106X_mc2017_realistic_v9-v1/MINIAODSIM",
        },
        "common_mc": {
            "good_run_json": "data/json/Collisions17/Cert_BCDEF_13TeV_UL2017_Collisions17_GoldenJSON.txt",
            "data_pu_distribution": "data/pileup/data/data17_09Aug2019_UltraLegacy/pileup_latest.txt",
            "roccor": "RoccoR2017UL.txt",
            "jec_version": "Summer19UL17_V5_MC",
            "jer_version": "Summer19UL17_JRV2",
            "global_tag": "106X_mc2017_realistic_v10",
        },
    },
    "2016ulpreVFP": {
        "dataBver1": {
            "dataset": "/SingleMuon/Run2016B-ver1_HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunBCD_V7_DATA",
        },
        "dataBver2": {
            "dataset": "/SingleMuon/Run2016B-ver2_HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunBCD_V7_DATA",
        },
        "dataC": {
            "dataset": "/SingleMuon/Run2016C-HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunBCD_V7_DATA",
        },
        "dataD": {
            "dataset": "/SingleMuon/Run2016D-HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunBCD_V7_DATA",
        },
        "dataE": {
            "dataset": "/SingleMuon/Run2016E-HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunEF_V7_DATA",
        },
        "dataF": {
            "dataset": "/SingleMuon/Run2016F-HIPM_UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16APV_RunEF_V7_DATA",
        },
        "common_data": {
            "good_run_json": "Collisions16/Cert_BCDEFearly_13TeV_Legacy2016_Collisions16_JSON.txt",
            "roccor": "RoccoR2016aUL.txt",
            "global_tag": "106X_dataRun2_v37",
        },
        "DYJetsToLL": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "DYJetsToLL_M-10to50": {
            "dataset": "/DYJetsToLL_M-10to50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_0J": {
            "dataset": "/DYJetsToLL_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "DYJetsToLL_1J": {
            "dataset": "/DYJetsToLL_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "DYJetsToLL_2J": {
            "dataset": "/DYJetsToLL_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_0To50": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-0To50_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_50To100": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-50To100_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_100To250": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-100To250_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_250To400": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-250To400_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_400To650": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-400To650_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_650ToInf": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-650ToInf_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "DYJetsToLL_MLM": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-madgraphMLM-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "DYJetsToLL_herwig": {
            "dataset": "/DYJetsToLL_M-50_TuneCH3_13TeV-madgraphMLM-herwig7/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "WW": {
            "dataset": "/WW_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WWTo2L2Nu": {
            "dataset": "/WWTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WZ": {
            "dataset": "/WZ_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WZTo2Q2L": {
            "dataset": "/WZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "WZTo3LNu": {
            "dataset": "/WZTo3LNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "ZZ": {
            "dataset": "/ZZ_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "ZZTo2Nu2Q": {
            "dataset": "/ZZTo2Nu2Q_5f_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "ZZTo2L2Nu": {
            "dataset": "/ZZTo2L2Nu_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "ZZTo2Q2L": {
            "dataset": "/ZZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "ZZTo4L": {
            "dataset": "/ZZTo4L_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM",
        },
        "ST_tw_top": {
            "dataset": "/ST_tW_top_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "ST_tw_antitop": {
            "dataset": "/ST_tW_antitop_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "ST_t-channel_top": {
            "dataset": "/ST_t-channel_top_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v3/MINIAODSIM",
        },
        "ST_t-channel_antitop": {
            "dataset": "/ST_t-channel_antitop_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v3/MINIAODSIM",
        },
        "TTbar": {
            "dataset": "/TTTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WJetsToLNu": {
            "dataset": "/WJetsToLNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v2/MINIAODSIM"
        },
        "WJetsToLNu_0J": {
            "dataset": "/WJetsToLNu_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WJetsToLNu_1J": {
            "dataset": "/WJetsToLNu_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "WJetsToLNu_2J": {
            "dataset": "/WJetsToLNu_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODAPVv2-106X_mcRun2_asymptotic_preVFP_v11-v1/MINIAODSIM",
        },
        "common_mc": {
            "good_run_json": "data/json/Collisions16/Cert_BCDEFearly_13TeV_Legacy2016_Collisions16_JSON.txt",
            "data_pu_distribution": "data/pileup/data/data16_21Feb2020_UltraLegacy/pileup_latest_preVFP.txt",
            "roccor": "RoccoR2016aUL.txt",
            "jec_version": "Summer19UL16APV_V7_MC",
            "jer_version": "Summer20UL16APV_JRV3",
            "global_tag": "106X_mcRun2_asymptotic_preVFP_v11",
        },
    },
    "2016ulpostVFP": {
        "dataF": {
            "dataset": "/SingleMuon/Run2016F-UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16_RunFGH_V7_DATA",
        },
        "dataG": {
            "dataset": "/SingleMuon/Run2016G-UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16_RunFGH_V7_DATA",
        },
        "dataH": {
            "dataset": "/SingleMuon/Run2016H-UL2016_MiniAODv2_BParking-v1/MINIAOD",
            "jec_version": "Summer19UL16_RunFGH_V7_DATA",
        },
        "common_data": {
            "good_run_json": "Collisions16/Cert_FlateGH_13TeV_Legacy2016_Collisions16_JSON.txt",
            "roccor": "RoccoR2016bUL.txt",
            "global_tag": "106X_dataRun2_v37",
        },
        "DYJetsToLL": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "DYJetsToLL_M-10to50": {
            "dataset": "/DYJetsToLL_M-10to50_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToMuMu": {
            "dataset": "/DYJetsToMuMu_H2ErratumFix_PDFExt_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v3/MINIAODSIM",
        },
        "DYJetsToTauTau": {
            "dataset": "/DYJetsToTauTau_M-50_AtLeastOneEorMuDecay_H2ErratumFix_PDF_TuneCP5_13TeV-powhegMiNNLO-pythia8-photos/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v3/MINIAODSIM",
        },
        "DYJetsToLL_0J": {
            "dataset": "/DYJetsToLL_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "DYJetsToLL_1J": {
            "dataset": "/DYJetsToLL_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "DYJetsToLL_2J": {
            "dataset": "/DYJetsToLL_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_0To50": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-0To50_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_50To100": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-50To100_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_100To250": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-100To250_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_250To400": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-250To400_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_400To650": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-400To650_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_PtZ_650ToInf": {
            "dataset": "/DYJetsToLL_LHEFilterPtZ-650ToInf_MatchEWPDG20_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "DYJetsToLL_MLM": {
            "dataset": "/DYJetsToLL_M-50_TuneCP5_13TeV-madgraphMLM-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "DYJetsToLL_herwig": {
            "dataset": "/DYJetsToLL_M-50_TuneCH3_13TeV-madgraphMLM-herwig7/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "WW": {
            "dataset": "/WW_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WWTo2L2Nu": {
            "dataset": "/WWTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WZ": {
            "dataset": "/WZ_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WZTo2Q2L": {
            "dataset": "/WZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "WZTo3LNu": {
            "dataset": "/WZTo3LNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "ZZ": {
            "dataset": "/ZZ_TuneCP5_13TeV-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "ZZTo2Nu2Q": {
            "dataset": "/ZZTo2Nu2Q_5f_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "ZZTo2L2Nu": {
            "dataset": "/ZZTo2L2Nu_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "ZZTo2Q2L": {
            "dataset": "/ZZTo2Q2L_mllmin4p0_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "ZZTo4L": {
            "dataset": "/ZZTo4L_TuneCP5_13TeV_powheg_pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "ST_tw_top": {
            "dataset": "/ST_tW_top_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "ST_tw_antitop": {
            "dataset": "/ST_tW_antitop_5f_inclusiveDecays_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM",
        },
        "ST_t-channel_top": {
            "dataset": "/ST_t-channel_top_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v3/MINIAODSIM",
        },
        "ST_t-channel_antitop": {
            "dataset": "/ST_t-channel_antitop_4f_InclusiveDecays_TuneCP5_13TeV-powheg-madspin-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v3/MINIAODSIM",
        },
        "TTbar": {
            "dataset": "/TTTo2L2Nu_TuneCP5_13TeV-powheg-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WJetsToLNu": {
            "dataset": "/WJetsToLNu_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v2/MINIAODSIM"
        },
        "WJetsToLNu_0J": {
            "dataset": "/WJetsToLNu_0J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WJetsToLNu_1J": {
            "dataset": "/WJetsToLNu_1J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "WJetsToLNu_2J": {
            "dataset": "/WJetsToLNu_2J_TuneCP5_13TeV-amcatnloFXFX-pythia8/RunIISummer20UL16MiniAODv2-106X_mcRun2_asymptotic_v17-v1/MINIAODSIM",
        },
        "common_mc": {
            "good_run_json": "data/json/Collisions16/Cert_FlateGH_13TeV_Legacy2016_Collisions16_JSON.txt",
            "data_pu_distribution": "data/pileup/data/data16_21Feb2020_UltraLegacy/pileup_latest_postVFP.txt",
            "roccor": "RoccoR2016bUL.txt",
            "jec_version": "Summer19UL16_V7_MC",
            "jer_version": "Summer20UL16_JRV3",
            "global_tag": "106X_mcRun2_asymptotic_v17",
        },
    },
}

scale_weights = [str(id) for id in range(1001, 1010)]
scale_weights_MLM = [str(id) for id in range(1001, 1046)]
# only take LHAPDFID 30600 into account
pdf_weights_MLM = [str(id) for id in range(1252, 1252 + 103)]
pdf_weights_aMC = [str(id) for id in range(1214, 1214 + 103)]
pdf_weights_madspin_4f = [str(id) for id in range(1500, 1500 + 103)]
pdf_weights_POWHEG = [str(id) for id in range(2000, 2000 + 103)]
ps_weights = ["nominal", "isrDefup", "isrDefdown", "fsrDefup", "fsrDefdown"]

cross_sections = {
    # https://twiki.cern.ch/twiki/bin/viewauth/CMS/StandardModelCrossSectionsat13TeV
    "DYJetsToLL": {
        "cross_section": 6077.22,  # +-1.49 (integration) +- 14.78 (pdf) +- 2% (scale)
        "cross_section_up": 6199.67,
        "cross_section_down": 5954.77,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToMuMu": {
        "cross_section": 6077.22 / 3,
        "cross_section_up": 6199.67 / 3,
        "cross_section_down": 5954.77 / 3,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_POWHEG,
        "ps_weights": ps_weights,
    },
    "DYJetsToTauTau": {
        "cross_section": 6077.22 / 3,
        "cross_section_up": 6199.67 / 3,
        "cross_section_down": 5954.77 / 3,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_POWHEG,
        "ps_weights": ps_weights,
    },
    # fractions are the part of the total generator xsec of all x-Jet samples
    "DYJetsToLL_0J": {
        "cross_section": 6077.22 * 0.797417146413568,
        "cross_section_up": 6199.67 * 0.797417146413568,
        "cross_section_down": 5954.77 * 0.797417146413568,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_1J": {
        "cross_section": 6077.22 * 0.148374046989264,
        "cross_section_up": 6199.67 * 0.148374046989264,
        "cross_section_down": 5954.77 * 0.148374046989264,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_2J": {
        "cross_section": 6077.22 * 0.0555935895441108,
        "cross_section_up": 6199.67 * 0.0555935895441108,
        "cross_section_down": 5954.77 * 0.0555935895441108,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    # Bug in PtZ binned sample caused exclusion of ~70% of total xsec
    # Z bosons with pT=0 (LO, no recoil at ME level) are removed.
    # PtZ cut is >0, not >=0
    "DYJetsToLL_PtZ_0To50": {
        "cross_section": 6077.22 * 0.231834448420725,
        "cross_section_up": 6199.67 * 0.231834448420725,
        "cross_section_down": 5954.77 * 0.231834448420725,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_PtZ_50To100": {
        "cross_section": 6077.22 * 0.0620196047922826,
        "cross_section_up": 6199.67 * 0.0620196047922826,
        "cross_section_down": 5954.77 * 0.0620196047922826,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_PtZ_100To250": {
        "cross_section": 6077.22 * 0.0149712151859343,
        "cross_section_up": 6199.67 * 0.0149712151859343,
        "cross_section_down": 5954.77 * 0.0149712151859343,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_PtZ_250To400": {
        "cross_section": 6077.22 * 0.000579586121051813,
        "cross_section_up": 6199.67 * 0.000579586121051813,
        "cross_section_down": 5954.77 * 0.000579586121051813,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_PtZ_400To650": {
        "cross_section": 6077.22 * 7.84191691302318e-05,
        "cross_section_up": 6199.67 * 7.84191691302318e-05,
        "cross_section_down": 5954.77 * 7.84191691302318e-05,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_PtZ_650ToInf": {
        "cross_section": 6077.22 * 7.3844717597635e-06,
        "cross_section_up": 6199.67 * 7.3844717597635e-06,
        "cross_section_down": 5954.77 * 7.3844717597635e-06,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_MLM": {
        "cross_section": 6077.22,  # +-1.49 (integration) +- 14.78 (pdf) +- 2% (scale)
        "cross_section_up": 6199.67,
        "cross_section_down": 5954.77,
        "scale_weights": scale_weights_MLM,
        "pdf_weights": pdf_weights_MLM,
        "ps_weights": ps_weights,
    },
    "DYJetsToLL_herwig": {
        "cross_section": 6077.22,  # +-1.49 (integration) +- 14.78 (pdf) +- 2% (scale)
        "cross_section_up": 6199.67,
        "cross_section_down": 5954.77,
        "scale_weights": scale_weights_MLM,
        "pdf_weights": pdf_weights_MLM,
        "ps_weights": [],
    },
    "DYJetsToLL_M-10to50": {
        "cross_section": 15810.0,  # from xsdb
        "cross_section_up": 15815.764,
        "cross_section_down": 15804.236,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    # https://twiki.cern.ch/twiki/bin/viewauth/CMS/StandardModelCrossSectionsat13TeV
    "WW": {
        "cross_section": 118.7,  # +2.5%-2.2%
        "cross_section_up": 121.7,
        "cross_section_down": 116.1,
        "scale_weights": [],
        "pdf_weights": [],
        "ps_weights": ps_weights,
    },
    # TTbar https://twiki.cern.ch/twiki/bin/view/LHCPhysics/TtbarNNLO
    # mtop=172.5GeV NNLO inclusive value= 831.76. BR(W->lnu)=3*0.1086
    # https://cms-gen-dev.cern.ch/xsdb/?searchQuery=DAS%3DTTTo2L2Nu_TuneCP5_13TeV-powheg-pythia8
    "TTbar": {
        "cross_section": 88.29,  # +4.8%-6.1%
        "cross_section_up": 92.53,
        "cross_section_down": 82.90,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_POWHEG,
        "ps_weights": ps_weights,
    },
    # Single Top xsecs from https://twiki.cern.ch/twiki/bin/view/LHCPhysics/SingleTopRefXsec
    # and https://twiki.cern.ch/twiki/bin/view/LHCPhysics/SingleTopNNLORef
    "ST_t-channel_top": {
        "cross_section": 145.0,  # +2.8 -1.9
        "cross_section_up": 147.8,
        "cross_section_down": 143.1,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_madspin_4f,
        "ps_weights": ps_weights,
    },
    "ST_t-channel_antitop": {
        "cross_section": 87.2,  # +1.8 -1.5
        "cross_section_up": 89.0,
        "cross_section_down": 85.7,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_madspin_4f,
        "ps_weights": ps_weights,
    },
    "ST_tw_top": {
        "cross_section": 35.85,
        "cross_section_up": 37.8,
        "cross_section_down": 33.9,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_POWHEG,
        "ps_weights": ps_weights,
    },
    "ST_tw_antitop": {
        "cross_section": 35.85,
        "cross_section_up": 37.8,
        "cross_section_down": 33.9,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_POWHEG,
        "ps_weights": ps_weights,
    },
    # WZ and ZZ not given in tables -> use value from xsdb
    "WZ": {
        "cross_section": 27.6,
        "cross_section_up": 28.0,
        "cross_section_down": 27.2,
        "scale_weights": [],
        "pdf_weights": [],
        "ps_weights": ps_weights,
    },
    "ZZ": {
        "cross_section": 12.17,
        "cross_section_up": 12.19,
        "cross_section_down": 12.15,
        "scale_weights": [],
        "pdf_weights": [],
        "ps_weights": ps_weights,
    },
    # https://twiki.cern.ch/twiki/bin/viewauth/CMS/StandardModelCrossSectionsat13TeV
    # Needs to be x3 for fermion BR
    "WJetsToLNu": {
        "cross_section": 20508.9 * 3,
        "cross_section_up": (20508.9 + np.sqrt(165.7**2 + 770.9**2)) * 3,
        "cross_section_down": (20508.9 - np.sqrt(88.2**2 + 770.9**2)) * 3,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "WJetsToLNu_0J": {
        "cross_section": 20508.9 * 3 * 0.812678269092906,
        "cross_section_up": (20508.9 + np.sqrt(165.7**2 + 770.9**2))
        * 3
        * 0.812678269092906,
        "cross_section_down": (20508.9 - np.sqrt(88.2**2 + 770.9**2))
        * 3
        * 0.812678269092906,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "WJetsToLNu_1J": {
        "cross_section": 20508.9 * 3 * 0.136514086118272,
        "cross_section_up": (20508.9 + np.sqrt(165.7**2 + 770.9**2))
        * 3
        * 0.136514086118272,
        "cross_section_down": (20508.9 - np.sqrt(88.2**2 + 770.9**2))
        * 3
        * 0.136514086118272,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
    "WJetsToLNu_2J": {
        "cross_section": 20508.9 * 3 * 0.0508076447888226,
        "cross_section_up": (20508.9 + np.sqrt(165.7**2 + 770.9**2))
        * 3
        * 0.0508076447888226,
        "cross_section_down": (20508.9 - np.sqrt(88.2**2 + 770.9**2))
        * 3
        * 0.0508076447888226,
        "scale_weights": scale_weights,
        "pdf_weights": pdf_weights_aMC,
        "ps_weights": ps_weights,
    },
}
