import os
from abc import ABCMeta

import law
import luigi
from analysis.framework.utils import Energy_Shifts
from luigi.util import inherits

law.contrib.load("wlcg")


class CommonConfig(luigi.Config):
    data_period = luigi.Parameter()
    dataset = luigi.Parameter()


@inherits(CommonConfig)
class ExcaliburConfig(luigi.Config):
    excalibur_config_version = luigi.Parameter()
    jet_radius = luigi.Parameter(default="4")


@inherits(CommonConfig)
class LumberjackConfig(luigi.Config):
    energy_shift = luigi.EnumParameter(enum=Energy_Shifts, default=Energy_Shifts.NONE)
    jec_uncertainty_source = luigi.Parameter(default="Total")
    excalibur_config_version = luigi.Parameter()
    jet_radius = luigi.Parameter(default="4")
    karma_config = luigi.Parameter(default="zjet_excalibur")
    selections = luigi.Parameter(default="zpt")
    task = luigi.Parameter(default="DATAShape")
    splitting = luigi.Parameter(default="ybys")


@inherits(CommonConfig)
class ExternalCMSSWTask(law.ExternalTask):
    @property
    def cmssw_path(self):
        return os.environ["CMSSW_DIR"]


@inherits(CommonConfig)
class AnalysisTask(law.Task):
    __metaclass__ = ABCMeta

    @property
    def cmssw_path(self):
        return os.environ["CMSSW_DIR"]

    def local_path(self, *path, name=None):
        if name is None:
            name = self.__class__.__name__
        parts = (name, self.data_period) + path
        return os.path.join(*parts)

    def local_target(self, *path, name=None):
        return law.LocalFileTarget(self.local_path(*path, name=name), fs="local_store")

    def local_plot_target(self, *path, name=None):
        if not name:
            name = self.__class__.__name__.replace("Plot", "")
        return law.LocalDirectoryTarget(
            self.local_path(*path, name=name), fs="local_plots"
        )

    def remote_path(self, *path, name=None):
        if name is None:
            name = self.__class__.__name__
        parts = (name, self.data_period) + path
        return os.path.join(*parts)

    def remote_target(self, *path, name=None):
        return law.wlcg.WLCGFileTarget(
            self.remote_path(*path, name=name), fs="nrg_tasks"
        )
