import os

import law
import luigi
from analysis.framework.dataset_map import dataset_map
from analysis.framework.tasks import AnalysisTask, ExternalCMSSWTask
from analysis.tasks.Skimming import SkimDataset


class ExcaliburDataConfigTemplate(ExternalCMSSWTask):
    def output(self):
        return law.LocalFileTarget(
            "{cmssw_path}/src/Excalibur/cfg/excalibur/zjet{data_period}/"
            "data_{data_period}_singlemuon.py.jinja2".format(
                cmssw_path=self.cmssw_path,
                data_period=self.data_period,
            )
        )


class CreateExcaliburDataConfig(AnalysisTask):
    excalibur_config_version = luigi.Parameter()
    jet_radius = luigi.Parameter(default="4")

    def requires(self):
        return {
            "template": ExcaliburDataConfigTemplate.req(self),
            "skim": SkimDataset.req(self),
        }

    def output(self):
        return law.LocalFileTarget(
            os.path.join(
                f"{self.cmssw_path}/src/Excalibur/cfg/excalibur",
                f"zjet{self.data_period}",
                self.excalibur_config_version,
                f"{self.data_period}_{self.dataset}.py",
            )
        )

    def run(self):
        from jinja2 import Template

        # read variables and build dict
        dataset_vars = dataset_map[self.data_period]["common_data"]
        dataset_vars.update(dataset_map[self.data_period][self.dataset])
        variables = dict(
            year=str(self.data_period).strip("ulUL_APVprepostVFP"),
            dataset_files=self.input()["skim"]["collection"].uri(),
            dataset=self.dataset,
            good_run_json=dataset_vars["good_run_json"],
            jet_radius=self.jet_radius,
            jec=dataset_vars["jec_version"],
            roccor=dataset_vars["roccor"],
        )
        # create file from jinja template
        iov = dataset_vars["jec_version"].split("_")[1][3:]  # get runs from jec name
        variables["iov"] = iov
        with open(self.input()["template"].abspath) as f:
            template = Template(f.read())
        config = template.render(variables)
        with self.output().localize("w") as tmp_file:
            with tmp_file.open("w") as g:
                g.write(config)
