import re

import law
import luigi
from analysis.framework.dataset_map import dataset_map
from analysis.framework.tasks import AnalysisTask
from analysis.framework.utils import excalibur_env, run_command
from analysis.tasks.Skimming import SkimDataset


class GetGeneratorWeights(AnalysisTask):
    def requires(self):
        return SkimDataset.req(self)

    def output(self):
        return law.LocalFileTarget(
            "{cmssw}/src/Excalibur/data/generator_weights/"
            "{data_period}/{dataset}.json".format(
                cmssw=self.cmssw_path,
                data_period=self.data_period,
                dataset=self.dataset,
            )
        )

    def run(self):
        # Kappa output of the skim
        filelist = self.input()["collection"].uri()
        # run tool to get generator weight
        command = ["getGeneratorWeight.py", "-n", "NONE"] + filelist
        code, out, error = run_command(
            command,
            env=excalibur_env,
            cwd="{}/src/Artus/KappaAnalysis/scripts".format(self.cmssw_path),
        )

        print("generator weight: %s" % out)

        result = dict(number_generated_events=-1.0, generator_weight=-1.0)
        n_gen_events = re.findall("n_events_generated:\\s\\d*", out)
        result["number_generated_events"] = n_gen_events[-1].split(" ")[-1]
        gen_weight = re.findall("generatorWeight:\\s\\d*.\\d*", out)
        result["generator_weight"] = gen_weight[-1].split(" ")[-1]

        print("Generated Events: {}".format(result["number_generated_events"]))
        print("GeneratorWeight: {}".format(result["generator_weight"]))
        self.output().dump(result, indent=4)


class AllGeneratorWeights(law.WrapperTask):
    data_period = luigi.Parameter()

    def requires(self):
        ret = []
        for dataset in dataset_map[self.data_period]:
            if (
                dataset
                in (
                    "common_mc",
                    "common_data",
                    "DYJetsToMuMu",
                    "DYJetsToTauTau",
                )
                or "data" in dataset
            ):
                continue
            ret.append(GetGeneratorWeights.req(self, dataset=dataset))
        return ret
