import law
import luigi

from analysis.framework.utils import DY_Sets, data_periods_ul
from analysis.tasks.PostProcessing import FitAcceptanceFakerate
from analysis.tasks.Plot import (
    PlotUnfoldedDataGen,
    PlotUnfoldedDataAlt,
    PlotUncertainties,
    PlotSignalBackground,
    # PlotCrossSectionRatio,
    PlotMigrationMatrix,
    PlotUnfoldingClosure,
)


class PlotAll(law.WrapperTask):
    excalibur_config_version = luigi.Parameter()
    selection_suffix = luigi.Parameter(default="2017")
    mc_dataset = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_combined)
    mc_dataset_alt = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_MLM)

    def requires(self):
        req = []
        periods = list(data_periods_ul) + ["Run2"]
        for period in periods:
            # Make plots of inputs
            req.append(
                [
                    PlotSignalBackground.req(
                        self,
                        data_period=period,
                        selections="reco" + self.selection_suffix,
                        ratio_range="0.7,1.3",
                    ),
                    PlotMigrationMatrix.req(
                        self,
                        data_period=period,
                        dataset=self.mc_dataset.name,
                        weight_name="totalWeight",
                    ),
                    PlotMigrationMatrix.req(
                        self,
                        data_period=period,
                        dataset=self.mc_dataset_alt.name,
                        weight_name="totalWeight",
                    ),
                    FitAcceptanceFakerate.req(
                        self,
                        data_period=period,
                        dataset=self.mc_dataset.name,
                        reco_weights=["totalWeight"],
                    ),
                    PlotUnfoldingClosure.req(
                        self, data_period=period, dataset=self.mc_dataset
                    ),
                ]
            )
            # Plot closure tests
            req.append(
                [
                    PlotUnfoldedDataAlt.req(
                        self,
                        dataset="data",
                        data_period=period,
                        mc_dataset=self.mc_dataset,
                        mc_dataset_alt=self.mc_dataset_alt,
                    ),
                    PlotUnfoldedDataGen.req(
                        self,
                        dataset=self.mc_dataset.name,
                        data_period=period,
                        input_is_mc=True,
                        input_weight="totalWeight",
                    ),
                ]
            )
            # Plot results
            req.append(
                [
                    PlotUnfoldedDataGen.req(
                        self, dataset="data", data_period=period, input_is_mc=False
                    ),
                    PlotUncertainties.req(
                        self, dataset="data", data_period=period, input_is_mc=False
                    ),
                ]
            )
        # # Plot year-to-year comparisons
        # req.append(
        #     [
        #         PlotCrossSectionRatio.req(
        #             self, data_period=period, data_period_den="Run2"
        #         )
        #         for period in data_periods_ul
        #     ]
        # )
        return req
