import luigi

from luigi.util import inherits
from analysis.framework.tasks import AnalysisTask, ExcaliburConfig
from analysis.framework.utils import run_command, karma_env, DY_Sets
from analysis.tasks.PostProcessing import UnravelCrossSection, UnravelUncertainties


@inherits(ExcaliburConfig)
class PlotCrossSectionRatio(AnalysisTask):
    dataset = luigi.Parameter(
        default="data"
        # default=DY_Sets.DYJetsToLL_combined.name
    )  # overwrite default from ExcaliburConfig
    input_is_mc = luigi.BoolParameter(default=False)
    mc_dataset = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_combined)
    input_weight = luigi.Parameter(default="weight")
    unfolding_weight = luigi.Parameter(default="totalWeight")
    gen_weight = luigi.Parameter("weight")

    selection_suffix = luigi.Parameter()

    data_period_den = luigi.Parameter()

    def requires(self):
        return {
            "num": UnravelCrossSection.req(self, data_period=self.data_period),
            "num_unc": UnravelUncertainties.req(self, data_period=self.data_period),
            "den": UnravelCrossSection.req(self, data_period=self.data_period_den),
            "den_unc": UnravelUncertainties.req(self, data_period=self.data_period_den),
        }

    def output(self):
        return self.local_plot_target(
            f"{self.excalibur_config_version}_{self.selection_suffix}_cuts",
            f"{self.dataset}-{self.input_weight}_unfolded_with_{self.mc_dataset.name}-{self.unfolding_weight}",
            f"{self.data_period}_{self.data_period_den}.pdf",
        )

    def run(self):
        command = [
            "palisade.py",
            "task",
            "zjet_excalibur",
            "plot_cross_section_ratio",
            "--data-period-num",
            self.data_period.replace("ul", ""),
            "--data-period-den",
            self.data_period_den.replace("ul", ""),
            "--filename-num",
            self.input()["num"].abspath,
            "--filename-den",
            self.input()["den"].abspath,
            "--filename-num-unc",
            self.input()["num_unc"].abspath,
            "--filename-den-unc",
            self.input()["den_unc"].abspath,
            "--weight-name",
            self.unfolding_weight,
            "--output-format",
            self.output().abspath,
        ]
        print(f"command: {command}")
        try:
            run_command(command, env=karma_env)
        except RuntimeError as e:
            self.output().remove()
            raise e
