import luigi

from luigi.util import inherits

from analysis.framework.tasks import AnalysisTask, ExcaliburConfig
from analysis.framework.utils import run_command, karma_env, DY_Sets
from analysis.tasks.PostProcessing import MergeUncertainties


@inherits(ExcaliburConfig)
class PlotJECUncertainties(AnalysisTask):
    dataset = luigi.Parameter(
        default="data"
        # default=DY_Sets.DYJetsToLL_combined.name
    )  # overwrite default from ExcaliburConfig
    input_is_mc = luigi.BoolParameter(default=False)
    mc_dataset = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_combined)
    input_weight = luigi.Parameter(default="weight")
    unfolding_weight = luigi.Parameter(default="totalWeight")
    gen_weight = luigi.Parameter("weight")

    bkg_variation_sfs = luigi.ListParameter(default=[1.5, 0.5])

    selection_suffix = luigi.Parameter()
    plot_range = luigi.Parameter(default="m0.15,0.15")

    def requires(self):
        unc = MergeUncertainties.req(self)
        req = {
            "data": unc.requires()["unf"],
            "unc": unc,
            # 'gen': Histograms(
            #     splitting="genybys", data_period=self.data_period,
            #     dataset=self.mc_dataset,
            #     task="MCShape",
            #     selections="gen{}".format(self.selection_suffix),
            #     excalibur_config_version=self.excalibur_config_version
            #     ),
        }
        return req

    def output(self):
        return self.local_plot_target(
            f"{self.excalibur_config_version}_{self.selection_suffix}_cuts",
            f"{self.dataset}-{self.input_weight}_unfolded_with_{self.mc_dataset.name}-{self.unfolding_weight}/",
        )

    def run(self):
        self.output().touch()
        command = [
            "palisade.py",
            "task",
            "zjet_excalibur",
            "plot_uncertainties_jec",
            "--data-period",
            self.data_period.replace("ul", ""),
            "--quantities",
            "zpt",
            "--filename-data",
            self.input()["data"].abspath,
            "--filename-unc",
            self.input()["unc"].abspath,
            "--weight-data",
            self.unfolding_weight,
            "--plot-range",
            self.plot_range,
            "--output-dir",
            self.output().abspath,
        ]
        try:
            run_command(command, env=karma_env)
        except RuntimeError as e:
            self.output().remove()
            raise e
