import datetime
import os

import luigi
from analysis.framework.quantities import ybys_bins
from analysis.framework.tasks import AnalysisTask
from analysis.framework.utils import karma_env, run_command
from analysis.tasks.PostProcessing import Histograms


class PlotRMSandGaus(AnalysisTask):
    dataset = luigi.Parameter(default="DYJetsToLL")
    data_period = luigi.Parameter()
    excalibur_config_version = luigi.Parameter()
    rebin_negative_bins = luigi.BoolParameter()

    def requires(self):
        return {
            "data": Histograms(
                splitting="globalzpt",
                data_period=self.data_period,
                dataset=self.dataset,
                task="Resolution",
                excalibur_config_version=self.excalibur_config_version,
                selections="response{}".format(self.data_period.replace("ul", "")),
            ),
        }

    def output(self):
        return self.local_plot_target(
            "{}/{}/{}/{}/{}/{}".format(
                datetime.datetime.now().strftime("%Y_%m_%d"),
                self.data_period,
                self.__class__.__name__,
                self.dataset,
                self.excalibur_config_version,
                "with_rebinning" if self.rebin_negative_bins else "without_rebinning",
            )
        )

    def run(self):
        # create ouput folder for result
        try:
            os.makedirs(os.path.dirname(self.output().abspath))
        except OSError as e:
            if e.errno != 17:
                raise e

        for ybys in ybys_bins:
            command = [
                "palisade.py",
                "task",
                "zjet_excalibur",
                "plot_rms_and_gaus",
                "--quantities",
                "zpt",
                "jet1y",
                "zy",
                "--data-period",
                self.data_period.replace("ul", ""),
                "--rebin-negative-bins" if self.rebin_negative_bins else "",
                "--ybys",
                ybys,
                "--weight",
                "totalWeight",
                "--filename",
                self.input()["data"].abspath,
                "--output-format",
                "{}/{{quantity[name]}}resolution/{}.png".format(
                    self.output().abspath, ybys
                ),
            ]
            print(f"command: {command}")

            try:
                run_command(command, env=karma_env, cwd=self.cmssw_path)
            except RuntimeError as e:
                self.output().remove()
                raise e
