import datetime
import os

import law
import luigi

from analysis.framework.tasks import AnalysisTask
from analysis.framework.utils import run_command, karma_env
from analysis.tasks.PostProcessing import Histograms


class PlotRatio(AnalysisTask):
    data_period = luigi.Parameter(default="None")
    plots_folder = luigi.Parameter()

    excalibur_config_version = luigi.Parameter()
    karma_config = luigi.Parameter(default="zjet_excalibur")

    selections = luigi.Parameter()

    data_period_num = luigi.Parameter()
    data_period_den = luigi.Parameter()
    weight_num = luigi.Parameter(default="totalWeight")
    weight_den = luigi.Parameter(default="totalWeight")
    useData = luigi.Parameter(default="False")
    quantities = luigi.Parameter()

    def requires(self):
        # datasets = ['data']
        # if self.useData == 'False':
        # datasets = ["DYJetsToLL"] #, "TTbar", "WZ", "ZZ", "ST", "WW"]

        # _ret = dict()
        # for d in datasets:
        #     _ret['num_'+d] = Histograms(splitting="ybys", data_period=self.data_period_num,
        #                                          dataset=d, task="DATAShape",
        #                                          excalibur_config_version=self.excalibur_config_version,
        #                                          karma_config=self.karma_config,
        #                                          selections=self.selections)
        #     _ret['den_'+d] = Histograms(splitting="ybys", data_period=self.data_period_den,
        #                                          dataset=d, task="DATAShape",
        #                                          excalibur_config_version=self.excalibur_config_version,
        #                                          karma_config=self.karma_config,
        #                                          selections=self.selections)
        # return _ret
        return {
            "num": Histograms(
                splitting="ybys",
                data_period=self.data_period_num,
                dataset="DYJetsToLL",
                task="DATAShape",
                excalibur_config_version=self.excalibur_config_version,
                karma_config=self.karma_config,
                selections=self.selections,
            ),
            "den": Histograms(
                splitting="ybys",
                data_period=self.data_period_num,
                dataset="DYJetsToLL_XJ",
                task="DATAShape",
                excalibur_config_version=self.excalibur_config_version,
                karma_config=self.karma_config,
                selections=self.selections,
            ),
        }

    def local_path(self, *path):
        return os.path.join(str(self.plots_folder), *path)

    def local_target(self, *path):
        return law.LocalFileTarget(self.local_path(*path))

    def output(self):
        return self.local_target(
            "{plots}/{date}/{excalibur}/{selections}/Ratio/"
            "{period_num}_{weight_num}-{period_den}_{weight_den}/{type}/".format(
                plots=self.plots_folder,
                date=datetime.datetime.now().strftime("%Y_%m_%d"),
                excalibur=self.excalibur_config_version,
                selections=self.selections,
                period_num=self.data_period_num,
                weight_num=self.weight_num,
                period_den=self.data_period_den,
                weight_den=self.weight_den,
                type="Data" if self.useData == "True" else "MC",
            )
        )

    def run(self):
        # _req = ["data"]
        # if self.useData == 'False':
        #      _req = ["DYJetsToLL", "TTbar", "WZ", "ZZ", "ST", "WW"]
        # fnames_num = [self.input()['num_'+d].abspath for d in _req]
        # fnames_den = [self.input()['den_'+d].abspath for d in _req]
        fnames_num = [self.input()["num"].abspath]
        fnames_den = [self.input()["den"].abspath]

        command = (
            [
                "palisade.py",
                "task",
                self.karma_config,
                "plot_ratio_quantity",
                "--quantities",
            ]
            + self.quantities.split()
            + ["--filenames-num"]
            + fnames_num
            + ["--filenames-den"]
            + fnames_den
            + [
                "--weight-num",
                self.weight_num,
                "--weight-den",
                self.weight_den,
                "--data-period-num",
                self.data_period_num.replace("ul", ""),
                "--data-period-den",
                self.data_period_den.replace("ul", ""),
                "--output-dir",
                self.output().abspath,
                "--output-format",
                "{quantity}.pdf",
                "--inclusive-only",
                "--normalize",
            ]
        )
        if self.useData == "True":
            command.append("--isData")
        print(f"command: {command}")
        try:
            run_command(command, env=karma_env, cwd=self.cmssw_path)
        except RuntimeError as e:
            self.output().remove()
            raise e
