import datetime
import os

import law
import luigi

from analysis.framework.tasks import AnalysisTask
from analysis.framework.utils import run_command, karma_env
from analysis.tasks.PostProcessing import Histograms


class PlotRatioSingleEra(AnalysisTask):
    data_period = luigi.Parameter(default="None")
    plots_folder = luigi.Parameter()

    excalibur_config_version = luigi.Parameter()
    karma_config = luigi.Parameter(default="zjet_excalibur")

    selections = luigi.Parameter()

    data_period_num = luigi.Parameter()
    dataset_num = luigi.Parameter()
    dataset_den = luigi.Parameter()
    data_period_den = luigi.Parameter()
    weight_num = luigi.Parameter(default="weight")
    weight_den = luigi.Parameter(default="weight")
    quantities = luigi.Parameter()

    def requires(self):
        _ret = dict()
        _ret["num"] = Histograms(
            splitting="ybys",
            data_period=self.data_period_num,
            dataset=self.dataset_num,
            task="DATAShape",
            excalibur_config_version=self.excalibur_config_version,
            karma_config=self.karma_config,
            selections=self.selections,
        )
        _ret["den"] = Histograms(
            splitting="ybys",
            data_period=self.data_period_den,
            dataset=self.dataset_den,
            task="DATAShape",
            excalibur_config_version=self.excalibur_config_version,
            karma_config=self.karma_config,
            selections=self.selections,
        )
        return _ret

    def local_path(self, *path):
        return os.path.join(str(self.plots_folder), *path)

    def local_target(self, *path):
        return law.LocalFileTarget(self.local_path(*path))

    def output(self):
        return self.local_target(
            "{plots}/{date}/{excalibur}/{selections}/Ratio/"
            "{period_num}_{dataset_num}_{weight_num}-"
            "{period_den}_{dataset_den}_{weight_den}/".format(
                plots=self.plots_folder,
                date=datetime.datetime.now().strftime("%Y_%m_%d"),
                excalibur=self.excalibur_config_version,
                selections=self.selections,
                period_num=self.data_period_num,
                dataset_num=self.dataset_num,
                weight_num=self.weight_num,
                period_den=self.data_period_den,
                dataset_den=self.dataset_den,
                weight_den=self.weight_den,
            )
        )

    def run(self):
        fname_num = self.input()["num"].abspath
        fname_den = self.input()["den"].abspath

        data_period_num = self.data_period_num.replace("ul", "")
        if self.dataset_num != "data":
            data_period_num += "_" + self.dataset_num.replace("data", "")
        data_period_den = self.data_period_den.replace("ul", "")
        if self.dataset_den != "data":
            data_period_den += "_" + self.dataset_den.replace("data", "")

        command = (
            [
                "palisade.py",
                "task",
                self.karma_config,
                "plot_ratio_quantity",
                "--quantities",
            ]
            + self.quantities.split()
            + [
                "--filenames-num",
                fname_num,
                "--filenames-den",
                fname_den,
                "--weight-num",
                self.weight_num,
                "--weight-den",
                self.weight_den,
                "--data-period-num",
                data_period_num,
                "--data-period-den",
                data_period_den,
                "--output-dir",
                self.output().abspath,
                "--output-format",
                "{quantity}.pdf",
                "--isData",
                "--inclusive-only",
            ]
        )
        print(f"command: {command}")
        try:
            run_command(command, env=karma_env, cwd=self.cmssw_path)
        except RuntimeError as e:
            self.output().remove()
            raise e
