import luigi
import os
import datetime

from analysis.framework.tasks import AnalysisTask
from analysis.framework.utils import run_command, karma_env
from analysis.tasks.PostProcessing import Histograms


class PlotResolution(AnalysisTask):
    dataset = luigi.Parameter()
    data_period = luigi.Parameter()
    excalibur_config_version = luigi.Parameter()
    plots_folder = luigi.Parameter()
    weight_name = luigi.Parameter()
    rebin_negative_bins = luigi.BoolParameter()
    selection_suffix = luigi.Parameter()

    def requires(self):
        return {
            "data": Histograms(
                splitting="globalzpt",
                data_period=self.data_period,
                dataset=self.dataset,
                task="Resolution",
                excalibur_config_version=self.excalibur_config_version,
                selections="matchedmigration{}".format(self.selection_suffix),
            )
        }

    def output(self):
        return self.local_plot_target(
            "{}/{}/{}_cuts/{}/{}/{}/{}/".format(
                datetime.datetime.now().strftime("%Y_%m_%d"),
                self.data_period,
                self.selection_suffix,
                self.__class__.__name__,
                self.dataset,
                self.excalibur_config_version,
                "with_rebinning" if self.rebin_negative_bins else "without_rebinning",
            )
        )

    def run(self):
        # create ouput folder for result
        try:
            os.makedirs(os.path.dirname(self.output().abspath))
        except OSError as e:
            if e.errno != 17:
                raise e

        command = [
            "palisade.py",
            "task",
            "zjet_excalibur",
            "plot_resolution",
            "--quantities",
            "zptresolution",
            "zyresolution",
            "jet1yresolution",
            "--data-period",
            self.data_period.replace("ul", ""),
            "--weight-name",
            self.weight_name,
            "--rebin-negative-bins" if self.rebin_negative_bins else "",
            "--filename",
            self.input()["data"].abspath,
            "--output-format",
            "{}/{{quantity[name]}}/{{globalzpt[name]}}.png".format(
                self.output().abspath
            ),
        ]
        print(f"command: {command}")
        try:
            run_command(command, env=karma_env, cwd=self.cmssw_path)
        except RuntimeError as e:
            self.output().remove()
            raise e
