import luigi

from luigi.util import inherits

from analysis.framework.tasks import AnalysisTask, ExcaliburConfig
from analysis.framework.utils import run_command, karma_env, DY_Sets
from analysis.tasks.PostProcessing import MergeUncertainties


@inherits(ExcaliburConfig)
class PlotUnfoldedDataAlt(AnalysisTask):
    dataset = luigi.Parameter(
        default="data"
        # default=DY_Sets.DYJetsToLL_combined.name
    )  # overwrite default from ExcaliburConfig
    input_is_mc = luigi.BoolParameter(default=False)
    mc_dataset = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_combined)
    mc_dataset_alt = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_MLM)
    input_weight = luigi.Parameter(default="weight")
    unfolding_weight = luigi.Parameter(default="totalWeight")
    gen_weight = luigi.Parameter("weight")

    selection_suffix = luigi.Parameter()

    def requires(self):
        # require the same unfolding/reravel as the uncertainty task.
        # This is a nightmare with the weights otherwise
        helper = MergeUncertainties.req(self)
        return {
            "unfolded": helper.requires()["unf"],
            "unfolded_alt": helper.requires()["unf_syst"],
        }

    def output(self):
        return self.local_plot_target(
            f"{self.excalibur_config_version}_{self.selection_suffix}_cuts",
            f"{self.dataset}-{self.input_weight}_unfolded_with_{self.mc_dataset}_alt_{self.mc_dataset_alt}-{self.unfolding_weight}/",
        )

    def run(self):
        command = [
            "palisade.py",
            "task",
            "zjet_excalibur",
            "plot_unfolded_data_alt",
            "--weight-gen",
            self.gen_weight,
            "--weight-unfolded",
            self.unfolding_weight,
            "--data-period",
            self.data_period.replace("ul", ""),
            "--ratio-range",
            "0.4,1.6",
            "--filename-unfolded",
            self.input()["unfolded"].abspath,
            "--filename-unfolded-alt",
            self.input()["unfolded_alt"].abspath,
            "--quantities",
            "zpt",
            "--output-format",
            "{}/unfolded_data_alt_{{ybys[name]}}_{{quantity[name]}}.pdf".format(
                self.output().abspath
            ),
        ]
        try:
            run_command(command, env=karma_env)
        except RuntimeError as e:
            self.output().remove()
            raise e
