import luigi
from luigi.util import inherits

from analysis.framework.tasks import AnalysisTask, ExcaliburConfig
from analysis.framework.utils import DY_Sets, karma_env, run_command
from analysis.tasks.PostProcessing import Histograms, MergeUncertainties


@inherits(ExcaliburConfig)
class PlotUnfoldedDataGen(AnalysisTask):
    dataset = luigi.Parameter(
        default="data"
        # default=DY_Sets.DYJetsToLL_combined.name
    )  # overwrite default from ExcaliburConfig
    input_is_mc = luigi.BoolParameter(default=False)
    mc_dataset = luigi.EnumParameter(enum=DY_Sets, default=DY_Sets.DYJetsToLL_combined)
    input_weight = luigi.Parameter(default="weight")
    unfolding_weight = luigi.Parameter(default="totalWeight")
    gen_weight = luigi.Parameter("weight")

    selection_suffix = luigi.Parameter()

    def requires(self):
        req = {
            "gen": Histograms(
                splitting="genybys",
                data_period=self.data_period,
                dataset=self.mc_dataset.name,
                task="MCShape",
                selections="gen{}".format(self.selection_suffix),
                excalibur_config_version=self.excalibur_config_version,
            ),
            "gen_lo": Histograms(
                splitting="genybys",
                data_period=self.data_period,
                dataset=DY_Sets.DYJetsToLL_MLM.name,
                task="MCShape",
                selections="gen{}".format(self.selection_suffix),
                excalibur_config_version=self.excalibur_config_version,
            ),
            "unc": MergeUncertainties.req(self),
        }
        req["unfolded"] = req["unc"].requires()["unf"]
        return req

    def output(self):
        return self.local_plot_target(
            f"{self.excalibur_config_version}_{self.selection_suffix}_cuts",
            f"{self.dataset}-{self.input_weight}_unfolded_with_{self.mc_dataset}-{self.unfolding_weight}/",
        )

    def run(self):
        command = [
            "palisade.py",
            "task",
            "zjet_excalibur",
            "plot_unfolded_reco_gen",
            "--weight-gen",
            self.gen_weight,
            "--weight-unfolded",
            self.unfolding_weight,
            "--data-period",
            self.data_period.replace("ul", ""),
            "--ratio-range",
            "0.4,1.6",
            "--filename-unfolded",
            self.input()["unfolded"].abspath,
            "--filename-unc",
            self.input()["unc"].abspath,
            "--filename-gen",
            self.input()["gen"].abspath,
            "--filename-gen-lo",
            self.input()["gen_lo"].abspath,
            "--filename-theo-lo",
            "/work/cverstege/QCD_shared/store/Theory/LO.root",
            "--filename-theo-nlo",
            "/work/cverstege/QCD_shared/store/Theory/NLO.root",
            "--filename-theo-nnlo",
            "/work/cverstege/QCD_shared/store/Theory/NNLO.root",
            "--quantities",
            "zpt",
            "--output-format",
            "{}/unfolded_data_gen_{{ybys[name]}}_{{quantity[name]}}.pdf".format(
                self.output().abspath
            ),
        ]
        try:
            run_command(command, env=karma_env)
        except RuntimeError as e:
            self.output().remove()
            raise e
