import datetime
import os
from itertools import combinations

import law
import luigi

from analysis.framework.utils import data_periods_ul
from analysis.framework.tasks import AnalysisTask
from analysis.tasks.Plot.PlotRatio import PlotRatio
from analysis.tasks.Plot.PlotDoubleRatio import PlotDoubleRatio


class RatioAllYears(AnalysisTask):
    data_period = luigi.Parameter(default="None")
    plots_folder = luigi.Parameter()

    excalibur_config_version = luigi.Parameter()
    karma_config = luigi.Parameter(default="zjet_excalibur")

    selections = luigi.Parameter()
    quantities = luigi.Parameter()

    def requires(self):
        _req = set()
        for num, den in combinations(data_periods_ul, 2):
            data_ratio = PlotRatio(
                plots_folder=self.plots_folder,
                excalibur_config_version=self.excalibur_config_version,
                selections=self.selections,
                data_period_num=num,
                weight_num="weight",
                data_period_den=den,
                weight_den="weight",
                useData="True",
                quantities=self.quantities,
            )
            mc_ratio = PlotRatio(
                plots_folder=self.plots_folder,
                excalibur_config_version=self.excalibur_config_version,
                selections=self.selections,
                data_period_num=num,
                weight_num="totalWeight",
                data_period_den=den,
                weight_den="totalWeight",
                useData="False",
                quantities=self.quantities,
            )
            double_ratio = PlotDoubleRatio(
                plots_folder=self.plots_folder,
                excalibur_config_version=self.excalibur_config_version,
                selections=self.selections,
                data_period_num=num,
                data_period_den=den,
                quantities=self.quantities,
            )
            _req.add(data_ratio)
            _req.add(mc_ratio)
            _req.add(double_ratio)
        return _req

    def local_path(self, *path):
        return os.path.join(str(self.plots_folder), *path)

    def local_target(self, *path):
        return law.LocalFileTarget(self.local_path(*path))

    def output(self):
        return self.local_target(
            "{}/{}/{}/{}/Ratio/".format(
                self.plots_folder,
                datetime.datetime.now().strftime("%Y_%m_%d"),
                self.selections,
                self.excalibur_config_version,
            )
        )

    def run(self):
        return
