import os

import law
import luigi
from analysis.framework.quantities import ybys_bins
from analysis.framework.utils import run_command, set_environment_variables

from .GridEval import Grid


class PlotSubprocessContrib(law.Task):
    order = luigi.Parameter(default="NNLO")
    pdf = luigi.Parameter(default="PDF4LHC21_40")

    def requires(self):
        return Grid.req(self)

    def output(self):
        name = self.__class__.__name__.replace("Plot", "")
        filelist = {}
        for ybys in ybys_bins:
            filelist[ybys] = law.LocalFileTarget(
                f"{name}/subproc_{ybys}_{self.order}_{self.pdf}.pdf",
                fs="local_plots",
            )
        return law.SiblingFileCollection(filelist)

    def run(self):
        self.output().dir.touch()
        fnlo_env = set_environment_variables(
            os.path.expandvars("$ANALYSIS_BASE/scripts/ini_fastNLO.sh")
        )
        for ybys, _d in ybys_bins.items():
            fname, ext = os.path.splitext(self.output()[ybys].abspath)
            run_command(
                [
                    "/work/cverstege/ZJet/fastNLO/tools/plotting/fnlo-py-subprocs.py",
                    "-o",
                    self.order,
                    "-p",
                    self.pdf,
                    "--filename",
                    fname,
                    "--format",
                    ext[1:],
                    "--title",
                    f"{_d['label']}",
                    "--xmin",
                    "25",
                    "--xmax",
                    "1000",
                    "--ymin",
                    "-0.15",
                    "--ymax",
                    "1.15",
                    self.input()[ybys].abspath,
                ],
                fnlo_env,
            )
