#!/bin/bash
#
# Checkout script for ZJet Analysis CMSSW
#########################################

export SCRAM_ARCH="slc7_amd64_gcc700"

source /cvmfs/cms.cern.ch/cmsset_default.sh

_CMSSW_VERSION="CMSSW_10_6_34"
_CMSSW_SCRAM_SUFFIX="ZJet"

_CMSSW_DIR="${_CMSSW_VERSION}"
if [ "${_CMSSW_SCRAM_SUFFIX}" != "" ]; then
  _CMSSW_DIR="${_CMSSW_DIR}_${_CMSSW_SCRAM_SUFFIX}"
fi

# checkout workflow
# =================

# -- checks

# check for CMSSW
if [ -z "${CMS_PATH}" ]; then
  echo "[ERROR] Cannot find CMSSW: environment variable \$CMS_PATH is not set!"
  echo "[INFO] Have you done 'source /cvmfs/cms.cern.ch/cmsset_default.sh'?"
fi

# -- initialization

# create a CMSSW working directory
echo "[INFO] Can create working area '${_CMSSW_DIR}'?"
if [ -d "${_CMSSW_DIR}" ]; then
  echo "[ERROR] Cannot create working area '${_CMSSW_DIR}': directory already exists!"
fi
scramv1 project -n "${_CMSSW_DIR}" CMSSW "${_CMSSW_VERSION}"

pushd "${_CMSSW_DIR}/src" || exit
eval "$(scramv1 runtime -sh)"

# initialize git repository from CMSSW
git cms-init

# -- apply CMSSW modifications, backports, etc. (user code)

# TODO?

# -- get some modules directly from github

# Kappa
if [ ! -d "Kappa" ]; then
  echo "Cloning Kappa"
  git clone git@github.com:KIT-CMS/Kappa.git
fi
if [ ! -d "KappaTools" ]; then
  echo "Cloning KappaTools"
  git clone git@github.com:KIT-CMS/KappaTools.git
fi

# Jet Toolbox
if [ ! -d "JMEAnalysis/JetToolbox" ]; then
  echo "Cloning JetToolbox"
  git clone git@github.com:cms-jet/JetToolbox.git JMEAnalysis/JetToolbox --branch jetToolbox_102X
fi

# Artus
if [ ! -d "Artus" ]; then
  echo "Cloning Artus"
  git clone git@github.com:KIT-CMS/Artus.git
fi

# Excalibur
if [ ! -d "Excalibur" ]; then
  echo "Cloning Excalibur"
  git clone git@github.com:KIT-CMS/Excalibur.git
fi

# JR Database
if [ ! -d "JRDatabase" ]; then
  echo "Cloning JRDatabase"
  git clone git@github.com:cms-jet/JRDatabase.git
fi

# Karma
if [ ! -d "Karma" ]; then
  echo "Cloning Karma"
  git clone git@github.com:dsavoiu/Karma.git
fi

# Karma Tasks
if [ ! -d "ZJetPostProcessing" ]; then
  echo "Cloning Karma Tasks"
  git clone git@gitlab.etp.kit.edu:cverstege/zjet-postprocessing.git ZJetPostProcessing --branch zjet_3d # TODO move to qcd group gitlab and main branch
fi

# -- compile using scram
echo "Building CMSSW..."
scram b clean
scram b -j32

popd || exit
if [ ! -d "${_CMSSW_DIR}/src/JECDatabase" ]; then
  if [ ! -d "JECDatabase" ]; then
    echo "Cloning JECDatabase"
    git clone --depth 1 git@github.com:cms-jet/JECDatabase.git
  fi
  echo "Copying JECFiles..."
  mkdir -p "${_CMSSW_DIR}/src/JECDatabase/textFiles"
  cp -r JECDatabase/textFiles/Summer19UL16*V7* ${_CMSSW_DIR}/src/JECDatabase/textFiles
  cp -r JECDatabase/textFiles/Summer19UL17*V5* ${_CMSSW_DIR}/src/JECDatabase/textFiles
  cp -r JECDatabase/textFiles/Summer19UL18*V5* ${_CMSSW_DIR}/src/JECDatabase/textFiles
fi

echo "CMSSW setup successful!"
