#!/usr/bin/env bash

# determine the directy of this file
if [ -n "$ZSH_VERSION" ]; then
    # shellcheck disable=SC2296
    this_file="${(%):-%x}"
else
    this_file="${BASH_SOURCE[0]}"
fi
this_dir="$( cd "$( dirname "$this_file" )" && pwd )"


action() {
    # LCG stack
    source /cvmfs/sft.cern.ch/lcg/views/LCG_105/x86_64-centos7-gcc12-opt/setup.sh
    # source grid-ui for gfal etc
    source /cvmfs/grid.cern.ch/centos7-ui-200122/etc/profile.d/setup-c7-ui-python3-example.sh

    _addpy() {
        [ -n "$1" ] && export PYTHONPATH="$1:$PYTHONPATH"
    }
    _addbin() {
        [ -n "$1" ] && export PATH="$1:$PATH"
    }

    export ANALYSIS_BASE="$this_dir"
    export ANALYSIS_SOFTWARE="$ANALYSIS_BASE/tmp/software"

    # set up CMSSW
    CMSSW_DIR_DEFAULT=$(realpath "$ANALYSIS_BASE/../CMSSW_10_6_30_ULRun2")
    if [ ! -s "$ANALYSIS_BASE/cmssw.conf" ]; then
        echo "Couldn't find CMSSW config at $ANALYSIS_BASE/cmssw.conf or empty"
        echo "    Fallback to default CMSSW directory $CMSSW_DIR_DEFAULT"
        export CMSSW_DIR="$CMSSW_DIR_DEFAULT"
        echo "    Writing CMSSW config to $ANALYSIS_BASE/cmssw.conf"
        echo "CMSSW_DIR=$CMSSW_DIR_DEFAULT" > "$ANALYSIS_BASE/cmssw.conf"
    else
        echo "Found non-empty CMSSW config $ANALYSIS_BASE/cmssw.conf"
        . "$ANALYSIS_BASE/cmssw.conf"
        export CMSSW_DIR="$CMSSW_DIR"
    fi

    # add python packages
    echo "Adding python packages..."
    _addpy "$ANALYSIS_BASE"
    _addpy "$ANALYSIS_BASE/luigi"
    _addbin "$ANALYSIS_BASE/luigi/bin"
    _addpy "$ANALYSIS_BASE/law"
    _addbin "$ANALYSIS_BASE/law/bin"
    # set up newer mplhep version
    if [ "$ZJET_REMOTE" != "1" ]; then
        python -m setuptools_scm -r "$ANALYSIS_BASE/mplhep"
    fi
    _addpy "$ANALYSIS_BASE/mplhep/src"

    # setup law
    echo "Setting up law..."
    export LAW_HOME="$ANALYSIS_BASE/tmp/.law"
    export LAW_CONFIG_FILE="$ANALYSIS_BASE/law.cfg"
    export LUIGI_CONFIG_PATH="$ANALYSIS_BASE/luigi.cfg"

    # shellcheck disable=SC1090
    source "$( law completion )"
}

action "$@"
